==> bootstrap-2.6.1.tgz: package/HandIndexThumb/HandIndexThumb.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const HandIndexThumb = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 16 16"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M6.75 1a.75.75 0 00-.75.75V9.5a.5.5 0 01-.854.354l-2.41-2.411a.517.517 0 00-.809.631l2.512 4.185 1.232 2.465a.5.5 0 00.447.276h6.302a.5.5 0 00.434-.252l1.395-2.442a2.5 2.5 0 00.317-.991l.272-2.715a1 1 0 00-.995-1.1H13.5v1a.5.5 0 11-1 0V7.154a4.208 4.208 0 00-.2-.26c-.187-.222-.368-.383-.486-.43-.124-.05-.392-.063-.708-.039a4.844 4.844 0 00-.106.01V8a.5.5 0 11-1 0V5.986c0-.167-.073-.272-.15-.314a1.657 1.657 0 00-.448-.182c-.179-.035-.5-.04-.816-.027l-.086.004V8a.5.5 0 11-1 0V1.75A.75.75 0 006.75 1zM8.5 4.466V1.75a1.75 1.75 0 10-3.5 0v6.543L3.443 6.736A1.517 1.517 0 001.07 8.588l2.491 4.153 1.215 2.43A1.5 1.5 0 006.118 16h6.302a1.5 1.5 0 001.302-.756l1.395-2.441a3.5 3.5 0 00.444-1.389l.272-2.715a2 2 0 00-1.99-2.199h-.582a5.114 5.114 0 00-.195-.248c-.191-.229-.51-.568-.88-.716-.364-.146-.846-.132-1.158-.108l-.132.012a1.26 1.26 0 00-.56-.642 2.634 2.634 0 00-.738-.288c-.31-.062-.739-.058-1.05-.046l-.048.002zm2.094 2.025z"
  }));
});
HandIndexThumb.displayName = 'HandIndexThumb';
export const HandIndexThumbDimensions = {
  height: 16,
  width: 16
};

==> bootstrap-2.11.0.tgz: package/HandIndexThumb/HandIndexThumb.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var HandIndexThumb = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 16 16"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M6.75 1a.75.75 0 00-.75.75V9.5a.5.5 0 01-.854.354l-2.41-2.411a.517.517 0 00-.809.631l2.512 4.185 1.232 2.465a.5.5 0 00.447.276h6.302a.5.5 0 00.434-.252l1.395-2.442a2.5 2.5 0 00.317-.991l.272-2.715a1 1 0 00-.995-1.1H13.5v1a.5.5 0 11-1 0V7.154a4.208 4.208 0 00-.2-.26c-.187-.222-.368-.383-.486-.43-.124-.05-.392-.063-.708-.039a4.844 4.844 0 00-.106.01V8a.5.5 0 11-1 0V5.986c0-.167-.073-.272-.15-.314a1.657 1.657 0 00-.448-.182c-.179-.035-.5-.04-.816-.027l-.086.004V8a.5.5 0 11-1 0V1.75A.75.75 0 006.75 1zM8.5 4.466V1.75a1.75 1.75 0 10-3.5 0v6.543L3.443 6.736A1.517 1.517 0 001.07 8.588l2.491 4.153 1.215 2.43A1.5 1.5 0 006.118 16h6.302a1.5 1.5 0 001.302-.756l1.395-2.441a3.5 3.5 0 00.444-1.389l.272-2.715a2 2 0 00-1.99-2.199h-.582a5.114 5.114 0 00-.195-.248c-.191-.229-.51-.568-.88-.716-.364-.146-.846-.132-1.158-.108l-.132.012a1.26 1.26 0 00-.56-.642 2.634 2.634 0 00-.738-.288c-.31-.062-.739-.058-1.05-.046l-.048.002zm2.094 2.025z"
  }));
});
HandIndexThumb.displayName = 'HandIndexThumb';
export var HandIndexThumbDimensions = {
  height: 16,
  width: 16
};
